Being able to quickly and easily visualize results is critical for efficient scientific work. `qcio` come with build-in visualizations for all objects.

Install the visualization module and its required dependencies:

```sh
python -m pip install qcio[view]
```

OR

```sh
python -m pip install qcio[all]

```

Then in a Jupyter Notebook import the `view` module and call `view.view(...)` on any `Structure` or `Results` object to instantly visualize your results. Click on the examples on the left to see this in action ✨!
